@@ -43,21 +43,21 @@
 #include <ieeefp.h>
 #endif
 
-//#ifdef SCYTHE_COMPILE_DIRECT
+#ifdef SCYTHE_COMPILE_DIRECT
 #include "matrix.h"
 #include "error.h"
 #include "algorithm.h"
 #include "distributions.h"
 #include "ide.h"
 #include "la.h"
-/* #else */
-/* #include "scythestat/matrix.h" */
-/* #include "scythestat/error.h" */
-/* #include "scythestat/algorithm.h" */
-/* #include "scythestat/distributions.h" */
-/* #include "scythestat/ide.h" */
-/* #include "scythestat/la.h" */
-/* #endif */
+#else
+#include "scythestat/matrix.h"
+#include "scythestat/error.h"
+#include "scythestat/algorithm.h"
+#include "scythestat/distributions.h"
+#include "scythestat/ide.h"
+#include "scythestat/la.h"
+#endif
 
 namespace scythe {
 
@@ -538,7 +538,7 @@ namespace scythe {
           report = rgamma1 (shape) / rate;
         else if (shape == 1)
           report = -std::log (runif ()) / rate;
-        else if (shape < 1)
+        else
           report = rgamma1 (shape + 1) 
             * std::pow (runif (), 1 / shape) / rate;
 
@@ -1039,7 +1039,7 @@ namespace scythe {
             ((mean + std::sqrt(-2*variance*std::log(z))) - below) + below;
         }
 
-        if (! finite(x)) {
+        if (! R_finite(x)) {
           SCYTHE_WARN("Mean extremely far from truncation point. "
               << "Returning truncation point");
           return below; 
@@ -1095,7 +1095,7 @@ namespace scythe {
             *( (newmu + std::sqrt(-2*variance*std::log(z))) - below) 
             + below;
         }
-        if (! finite(x)) {
+        if (! R_finite(x)) {
           SCYTHE_WARN("Mean extremely far from truncation point. "
               << "Returning truncation point");
           return above; 
@@ -1164,7 +1164,7 @@ namespace scythe {
               * ((mean + std::sqrt(-2 * variance * std::log(z))) 
                 - below) + below;
           }
-          if (! finite(x)) {
+          if (! R_finite(x)) {
             SCYTHE_WARN("Mean extremely far from truncation point. "
                 << "Returning truncation point");
             return below; 
@@ -1234,7 +1234,7 @@ namespace scythe {
               * ((newmu + std::sqrt(-2 * variance * std::log(z)))
                   - below) + below;
           }
-          if (! finite(x)) {
+          if (! R_finite(x)) {
             SCYTHE_WARN("Mean extremely far from truncation point. "
                 << "Returning truncation point");
             return above; 
@@ -1277,7 +1277,7 @@ namespace scythe {
           
         for (unsigned int i = 0; i < v; ++i) {
           alpha = C * rnorm(Sigma.rows(), 1, 0, 1);
-          A = A + (alpha * (t(alpha)));
+          A += (alpha * (t(alpha)));
         }
 
         return A;
@@ -1317,7 +1317,7 @@ namespace scythe {
         for (ait = alpha.begin_f(); ait != alast; ++ait) {
           *yit = rgamma(*ait, 1);
           ysum += *yit;
-          ++ait;
+          ++yit;
         }
 
         y /= ysum;
